@@ -5,7 +5,7 @@
 from __future__ import print_function
 
 import bitarray
-import numpy
+import numpy  # type: ignore
 
 a = bitarray.bitarray('100011001001')
 print(a)
@@ -16,6 +16,6 @@ print(repr(b))
 
 # ndarray  ->  bitarray
 c = bitarray.bitarray()
-c.pack(b.tostring())
+c.pack(b.tobytes())
 
 assert a == c
